import React, { useEffect, useMemo, useRef, useState } from 'react'
import { useArmBotStore } from '../../../../../store/simulation/useArmBotStore';
import { useFrame, useThree } from '@react-three/fiber';
import * as THREE from "three"
import { usePlayButtonStore } from '../../../../../store/usePlayButtonStore';

function RoboticArmAnimator({ armUuid, HandleCallback, currentPhase, ikSolver, targetBone, robot, logStatus, groupRef, processes, armBotCurveRef, path }: any) {
    const { armBots } = useArmBotStore();
    const { scene } = useThree();
    const restSpeed = 0.1;
    const restPosition = new THREE.Vector3(0, 1, -1.6);
    const initialCurveRef = useRef<THREE.CatmullRomCurve3 | null>(null);
    const initialStartPositionRef = useRef<THREE.Vector3 | null>(null);
    const [initialProgress, setInitialProgress] = useState(0);
    const [progress, setProgress] = useState(0);
    const [needsInitialMovement, setNeedsInitialMovement] = useState(true);
    const [isInitializing, setIsInitializing] = useState(true);
    const { isPlaying } = usePlayButtonStore();
    const statusRef = useRef("idle");
    // Create a ref for initialProgress
    const initialProgressRef = useRef(0);
    const [currentPath, setCurrentPath] = useState<[number, number, number][]>([]);

    useEffect(() => {
        
        setCurrentPath(path)
    }, [path])

    useEffect(() => {

    }, [currentPath])

    useFrame((_, delta) => {
        if (!ikSolver || !currentPath || currentPath.length === 0) return;

        const bone = ikSolver.mesh.skeleton.bones.find(
            (b: any) => b.name === targetBone
        );
        if (!bone) return;

        // Ensure currentPath is a valid array of 3D points, create a CatmullRomCurve3 from it
        const curve = new THREE.CatmullRomCurve3(
            currentPath.map(point => new THREE.Vector3(point[0], point[1], point[2]))
        );


        const next = initialProgressRef.current + delta * 0.5;
        if (next >= 1) {
            // bone.position.copy(restPosition);
            HandleCallback(); // Call the callback when the path is completed
            initialProgressRef.current = 0; // Set ref to 1 when done
        } else {
            const point = curve.getPoint(next); // Get the interpolated point from the curve
            bone.position.copy(point); // Update the bone position along the curve
            initialProgressRef.current = next; // Update progress
        }

        ikSolver.update();
    });



    return (
        <></>
    )
}

export default RoboticArmAnimator;